//    QtLockscreen
//    Copyright (C) 2011 Paolo Iommarini
//    sakya_tg@yahoo.it
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#ifndef LSWIFI_H
#define LSWIFI_H
#include "lswidget.h"

class LsWifi : public QObject, public LsWidget
{
    Q_OBJECT
public:
    LsWifi(QString name="");

    void paint(QPainter *painter, const QStyleOptionGraphicsItem *option,
               QWidget *widget);
    void applySettings();

private:
    bool m_Connected;
    QString m_Wifi;
    QString m_Gprs;
    QPixmap m_Image;

private slots:
    void netStateChanged(QString, QString type, QString state, QString);
};

#endif // LSWIFI_H
